coop-tag
===============================================
Add-on for django-coop for managing tags with django-taggit, adding URI and language fields for proper export following the CommonTag RDF vocabulary.

Installation requires several custom modules::
hg+https://bitbucket.org/quinode/django-taggit-autosuggest#egg=taggit_autosuggest
git+git://github.com/jonasgeiregat/django-templatetag-sugar.git#egg=templatetag_sugar
git+https://github.com/quinode/django-taggit-templatetags#egg=taggit_templatetags



License
=======
coop-tag uses the same license as Django (BSD).
coop-tag development was funded by `CREDIS <http://credis.org/>`_, FSE (European Social Fund) and Conseil Regional d'Auvergne.
